@@ -255,7 +255,7 @@ class ImportContainer(BaseContainer):
 
                     # Remove reverse FK fields
                     for relation in model_meta.related_objects:
-                        if isinstance(relation, ManyToOneRel):
+                        if isinstance(relation, ManyToOneRel) and relation.related_name:
                             obj.fields.pop(relation.related_name, None)
 
                 # -------------------
