@@ -1,5 +1,5 @@
-
 import io
+import uuid
 from dataclasses import dataclass, field, asdict
 from django.apps import registry
 from django.db.models import Model
@@ -37,7 +37,10 @@ class ID:
         return registry.apps.get_model(*kind.split(':'))
 
     def serialize(self):
-        return asdict(self)
+        d = asdict(self)
+        if isinstance(self.pk, uuid.UUID):
+            d['pk'] = str(d['pk'])
+        return d
 
     @classmethod
     def to_yaml(cls, representer, node):
